/*******************************************************************************
Project: Effect of COVID on workers
Author: Sarah Wahby wahby001@umn.edu
Purpose: average stringency graph for Egypt, Jordan, Morocco, Sudan, Tunisia in 
the period April-June 2021
Data: our world in data downloaded on February 20th 2022
Created: Feb 20th, 2022
*******************************************************************************/

clear all
set more off

*Graph formatting setup
grstyle clear 

*Initializing grstyle
grstyle init

*Graph formatting setup
*Font
graph set window fontface "Calibri"
grstyle set size 10pt: heading
grstyle set size 10pt: subheading axis_title
grstyle set size 10pt: tick_label key_label

*Starting with the basic style
grstyle set plain
*Setting to ILO colors in CMYK
/* ordered grstyle set color "38 35 89" "0 85 167" "2 181 207" "205 216 228"  "144 204 130" "248 196 35" "231 77 94" "133 0 85" 
*/
grstyle set color "38 35 89" "2 181 207" "144 204 130" "231 77 94" "248 196 35"   "133 0 85" "0 85 167" "205 216 228" 
*Setting font size generally to 12 (does not get bar labels)
grstyle set size 12pt: axis_title tick_label key_label text_option subheading
*Setting graph size to 6.7 inches wide 3.2 high
grstyle set graphsize 3.2 6.7
*Turning off grids with width zero
grstyle set linewidth 0: major_grid minor_grid
*Making axes grey
grstyle set color gs7: axisline tick major_grid xyline minor_grid minortick matrix matrixmarkline grid refmarker refmarkline



import excel using "Data/Do files/Workers paper/Stringency graph/owid-covid-data -20220220.xlsx", clear first
keep if inlist(location, "Egypt", "Morocco", "Jordan", "Sudan", "Tunisia", "World")
gen date2=date(date, "YMD")
format date2 %td
gen month=mofd(date2)
format month %tmMon._CCYY


collapse (sum) new_cases_per_million new_deaths_per_million (mean) stringency_index (max) people_vaccinated_per_hundred , by (location month)

*people_vaccinated_per_hundred: Total number of people who received at least one vaccine dose per 100 people in the total population

rename people_vaccinated_per_hundred vaccinated_per_hundred

reshape wide new_cases_per_million new_deaths_per_million  vaccinated_per_hundred stringency_index, i(month) j(location) s


drop stringency_indexWorld

*create average stringency in the world
egen stringency_indexWorld= rowmean(stringency_index*)


foreach var of varlist new_cases_per_million* {
replace `var'=`var'/1000
}



**** Stringency index ****

format %9.0f stringency_index*
graph twoway (connected stringency_indexEgypt month, msymbol(O)) ///
(connected stringency_indexJordan month, msymbol(D)) ///
(connected stringency_indexMorocco month, msymbol(T)) ///
(connected stringency_indexTunisia month, msymbol(S)) ///
(connected stringency_indexSudan month, msymbol(X)) ///
(connected stringency_indexWorld month, lwidth(thick) msymbol(none)) ///
 if month>tm(2020m2) &  month<tm(2022m2), ///
ytitle(Stringency index) ylabel(0(20)100, nogrid) xtitle(Month) tlabel(2020m3(3)2022m1, angle(45)) legend(label(1 "Egypt") ///
label(2 "Jordan") label(3 "Morocco") label(4 "Tunisia") label(5 "Sudan") label(6 "World") rows(2)) plotregion(margin(zero))

graph save "Data/Do files/Workers paper/grph png tables/Stringency_workers.gph", replace
graph export "Data/Do files/Workers paper/grph png tables/Stringency_workers.png", replace width (1500)
