/*COVID-19 Workers Paper Models
Author: RC, CK, RA
Original: November 1 2021
Updated: 2022.06.30
Version: 20 REP

*/

*Graph formatting setup
grstyle clear 

*Initializing grstyle
grstyle init

*Graph formatting setup
*Font
graph set window fontface "Calibri"
grstyle set size 10pt: heading
grstyle set size 10pt: subheading axis_title
grstyle set size 10pt: tick_label key_label

*Starting with the basic style
grstyle set plain
*Setting to ILO colors in CMYK
/* ordered grstyle set color "38 35 89" "0 85 167" "2 181 207" "205 216 228"  "144 204 130" "248 196 35" "231 77 94" "133 0 85" 
*/
grstyle set color "38 35 89" "2 181 207" "144 204 130" "231 77 94" "248 196 35"   "133 0 85" "0 85 167" "205 216 228" 
*Setting font size generally to 12 (does not get bar labels)
grstyle set size 12pt: axis_title tick_label key_label text_option subheading
*Setting graph size to 6.7 inches wide 3.2 high
grstyle set graphsize 3.2 6.7
*Turning off grids with width zero
grstyle set linewidth 0: major_grid minor_grid
*Making axes grey
grstyle set color gs7: axisline tick major_grid xyline minor_grid minortick matrix matrixmarkline grid refmarker refmarkline

use "Data/Eat/Workers analysis data.dta", clear

estimates clear 

******Mlogit model**********

*tabulate covariates
tab lm_stat
tab init_lmstat
tab wave
tab country 
tab sex
tab agegrp3 
tab educ3 

*Label waves
la def Lwave 1 "11/20" 2 "2/21" 3 "4/21" 4 "6/21" 5 "8/21"
la val wave Lwave

*Define covariates
global covs i.wave b2.init_lmstat b5.firm_ind_w0 b1.sex b1.agegrp3 b1.educ3 

global int i.wave#b2.init_lmstat i.wave#b5.firm_ind_w0 i.wave#b1.sex i.wave#b1.agegrp3 i.wave#b1.educ3 



*****Mlogit model*****

foreach num of numlist 400 504 729 788 818 {
 mlogit lm_stat $covs b1.income_cat [aw=ind_wt] if country==`num', base(1) rrr

estimate store mlogit_main_`num'

mlogit lm_stat $covs b1.income_cat $int i.wave#b1.income_cat [aw=ind_wt] if country==`num', base(1) rrr

estimate store mlogit_int_`num'

**margins for income
foreach num2 of numlist 1/3 {

margins wave#1.income_cat wave#2.income_cat wave#3.income_cat wave#4.income_cat, post predict(outcome(`num2')) noestimcheck

estimates store mfx_mlogit_inc_`num'_`num2'

estimates restore mlogit_int_`num'
}

**margins for initial labor market status
foreach num2 of numlist 1/3 {

 margins wave#1.init_lmstat wave#2.init_lmstat wave#3.init_lmstat wave#4.init_lmstat wave#5.init_lmstat wave#6.init_lmstat wave#7.init_lmstat, post predict(outcome(`num2')) noestimcheck

estimates store mfx_mlogit_lmstat_`num'_`num2'

estimates restore mlogit_int_`num'


}
*/
*Test IIA assumption

foreach num of numlist 400 504 729 788 818 {

preserve

keep if country==`num'

mlogit lm_stat $covs b1.income_cat, base(1) rrr
mlogtest, iia

mlogit lm_stat $covs b1.income_cat $int i.wave#b1.income_cat, base(1) rrr
mlogtest, iia

restore
}



/*
**margins for sex
foreach num2 of numlist 1/3 {

margins wave#1.sex wave#2.sex, post predict(outcome(`num2')) noestimcheck

estimates store mfx_mlogit_sex_`num'_`num2'

estimates restore mlogit_int_`num'
}
*/

}

*Table A4/A5

esttab mlogit_main_* mlogit_int_* using "Data/Do files/Workers paper/grph png tables/mlogit.csv", cells(b(star fmt(3)) se(par)) stats(N r2_p, labels("(N (Obs.)" `"Psuedo R-sq."') fmt(%9.0g %9.3f)) varlabels(_cons "Constant" 2.wave "Feb. 2021" 3.wave "April 2021" 4.wave "June 2021" 5.wave "Aug. 2021") legend unstack replace collabels(none)noomit nomtitles nobase eform depvars refcat(1.init_lmstat "Feb. 2020 labor market status (Public wage omit.)" 2.sex "Sex (Male omit.)" 2.wave "Wave (First wave omit.)" 2.agegrp3 "Age group (18-29 omitted)" 2.educ3 "Education  (basic or less omit.)" 2.income_cat "Feb. 2020 income (first quart. omit.)" 1.firm_ind_w0 "Industry (Services omit.)" 2.wave#1.init_lmstat "Wave and Feb. 2020 labor market status int." 2.wave#1.firm_ind_w0 "Wave and Feb. 2020 industry int." 2.wave#2.sex "Wave and sex int." 2.wave#2.agegrp3 "Wave and age int." 2.wave#2.educ3 "Wave and educ. int." 2.wave#2.income_cat "Wave and Feb. 2020 income int.", label(" ")) label order(2.wave 3.wave 4.wave 5.wave ?.init_lmstat ?.firm_ind_w0 2.sex ?.agegrp3 ?.educ3 ?.income_cat ///
2.wave#*init_lmstat 3.wave#*init_lmstat 4.wave#*init_lmstat 5.wave#*init_lmstat 2.wave#*firm_ind_w0 3.wave#*firm_ind_w0 4.wave#*firm_ind_w0 5.wave#*firm_ind_w0 2.wave#2.sex 3.wave#2.sex 4.wave#2.sex 5.wave#2.sex 2.wave#*agegrp3 3.wave#*agegrp3 4.wave#*agegrp3 5.wave#*agegrp3 2.wave#*educ3 3.wave#*educ3 4.wave#*educ3 5.wave#*educ3  2.wave#*income_cat 3.wave#*income_cat 4.wave#*.income_cat 5.wave#*.income_cat) mlabel("Jordan" "Morocco" "Sudan" "Tunisia" "Egypt" "Jordan" "Morocco" "Sudan" "Tunisia" "Egypt")


*Income graph
foreach num of numlist 400 504 729 788 818 { 
	foreach num2 of numlist 1/3 {
estimates restore mfx_mlogit_inc_`num'_`num2'

local c_name: label Lcountry_code `num'
di "`c_name'"

local c_stat: label Llm_stat `num2'
di "`c_stat'"
 
mplotoffset, xdim(wave) ylabel(0(.2)1) legend(row(1)) plot1opts(msymbol(O)  msize(small)) plot2opts(msymbol(T) msize(small)) plot3opts(msymbol(D)  msize(small)) plot4opts(msymbol(S)  msize(small))  xscale(range(1(1)5)) xlabel(, angle(25)) title("`c_name': `c_stat'", size(large)) plotregion(margin(sides)) ytitle("Probability") legend(row(1) span size(small)) xtitle("")

graph save "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_`num'_`num2'.gph", replace
graph export "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_`num'_`num2'.png", replace width(1500)

}
}


grc1leg "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_400_1.gph"  "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_400_2.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_400_3.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_504_1.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_504_2.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_504_3.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_729_1.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_729_2.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_729_3.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_788_1.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_788_2.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_788_3.gph"  "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_818_1.gph"  "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_818_2.gph"   "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_818_3.gph", col(3) row(5) imargin(tiny)

graph display, xsize(10) ysize(15)

*Figure 5

graph save "Data/Do files/Workers paper/grph png tables/WP_mfx_inc.gph", replace
graph export "Data/Do files/Workers paper/grph png tables/WP_mfx_inc.png", replace width(1500)


*Initial labour market status graph
foreach num of numlist 400 504 729 788 818 { 
	foreach num2 of numlist 1/3 {
estimates restore mfx_mlogit_lmstat_`num'_`num2'

local c_name: label Lcountry_code `num'
di "`c_name'"

local c_stat: label Llm_stat `num2'
di "`c_stat'"
 
mplotoffset, xdim(wave) ylabel(0(.2)1) legend(row(1)) plot1opts(msymbol(O)  msize(small)) plot2opts(msymbol(T) msize(small)) plot3opts(msymbol(D)  msize(small)) plot4opts(msymbol(S)  msize(small)) plot5opts(msymbol(X)  msize(small)) xscale(range(1(1)5)) xlabel(, angle(25)) title("`c_name': `c_stat'", size(large)) plotregion(margin(sides)) ytitle("Probability") legend(row(5) size(vsmall)) xtitle("")

graph save "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_`num'_`num2'.gph", replace
graph export "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_`num'_`num2'.png", replace width(1500)

}
}


grc1leg "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_400_1.gph"  "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_400_2.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_400_3.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_504_1.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_504_2.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_504_3.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_729_1.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_729_2.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_729_3.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_788_1.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_788_2.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_788_3.gph"  "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_818_1.gph"  "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_818_2.gph"   "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_818_3.gph", col(3) row(5) imargin(tiny)

graph display, xsize(10) ysize(15)

*Figure 4

graph save "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat.gph", replace
graph export "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat.png", replace width(1500)



**Sex graph
/* foreach num of numlist 400 504 729 788 818 { 
	foreach num2 of numlist 1/3 {
estimates restore mfx_mlogit_sex_`num'_`num2'

local c_name: label Lcountry_code `num'
di "`c_name'"

local c_stat: label Llm_stat `num2'
di "`c_stat'"
 
mplotoffset, xdim(wave) ylabel(0(.2)1) legend(row(1)) plot1opts(msymbol(O)  msize(small)) plot2opts(msymbol(T) msize(small))  xscale(range(1(1)5)) xlabel(, angle(25)) title("`c_name': `c_stat'", size(large)) plotregion(margin(sides)) ytitle("Probability") legend(row(2) size(small))

graph save "Data/Do files/Workers paper/grph png tables/WP_mfx_sex_`num'_`num2'.gph", replace
graph export "Data/Do files/Workers paper/grph png tables/WP_mfx_sex_`num'_`num2'.png", replace width(1500)

}
}


grc1leg "Data/Do files/Workers paper/grph png tables/WP_mfx_sex_400_1.gph"  "Data/Do files/Workers paper/grph png tables/WP_mfx_sex_400_2.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_sex_400_3.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_sex_504_1.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_sex_504_2.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_sex_504_3.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_sex_729_1.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_sex_729_2.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_sex_729_3.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_sex_788_1.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_sex_788_2.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_sex_788_3.gph"  "Data/Do files/Workers paper/grph png tables/WP_mfx_sex_818_1.gph"  "Data/Do files/Workers paper/grph png tables/WP_mfx_sex_818_2.gph"   "Data/Do files/Workers paper/grph png tables/WP_mfx_sex_818_3.gph", col(3) row(5) 

graph display, xsize(10) ysize(15)

graph save "Data/Do files/Workers paper/grph png tables/WP_mfx_sex.gph", replace
graph export "Data/Do files/Workers paper/grph png tables/WP_mfx_sex.png", replace width(1500)
*/

******Tobit model************
*Hours
tab cor29

foreach num of numlist 400 504 729 788 818 {

tobit cor29 $covs b1.income_cat [aw=ind_wt] if country==`num', ll(0)

estimate store tobit_main_`num'

tobit cor29 $covs b1.income_cat $int i.wave#b1.income_cat [aw=ind_wt] if country==`num', ll(0)

estimate store tobit_int_`num'


**margins for income
margins wave#1.income_cat wave#2.income_cat wave#3.income_cat wave#4.income_cat, post noestimcheck 

estimates store mfx_tobit_inc_`num'

estimates restore tobit_int_`num'

**margins for initial labor market status
margins wave#1.init_lmstat wave#2.init_lmstat wave#3.init_lmstat wave#4.init_lmstat wave#5.init_lmstat, post noestimcheck

estimates store mfx_tobit_lmstat_`num'

estimates restore tobit_int_`num'
}

*Table A6/A7

esttab tobit_main_* tobit_int_* using "Data/Do files/Workers paper/grph png tables/tobit.csv", cells(b(star fmt(3)) se(par)) stats(N r2_p, labels("(N (Obs.)" `"Psuedo R-sq."') fmt(%9.0g %9.3f)) varlabels(_cons "Constant" 2.wave "Feb. 2021" 3.wave "April 2021" 4.wave "June 2021" 5.wave "Aug. 2021") replace noomit nobase refcat(1.init_lmstat "Feb. 2020 labor market status (Public wage omit.)" 2.sex "Sex (Male omit.)" 2.wave "Wave (First wave omit.)" 2.agegrp3 "Age group (18-29 omitted)" 2.educ3 "Education  (basic or less omit.)" 1.firm_ind_w0 "Industry (Services omit.)" 2.income_cat "Feb. 2020 income (first quart. omit.)"  2.wave#1.init_lmstat "Wave and Feb. 2020 labor market status int." 2.wave#1.firm_ind_w0 "Wave and Feb. 2020 industry int." 2.wave#2.sex "Wave and sex int." 2.wave#2.agegrp3 "Wave and age int." 2.wave#2.educ3 "Wave and educ. int." 2.wave#2.income_cat "Wave and Feb. 2020 income int.", label(" ")) label order(2.wave 3.wave 4.wave 5.wave ?.init_lmstat ?.firm_ind_w0 2.sex ?.agegrp3 ?.educ3 ?.income_cat ///
2.wave#*init_lmstat 3.wave#*init_lmstat 4.wave#*init_lmstat 5.wave#*init_lmstat 2.wave#*firm_ind_w0 3.wave#*firm_ind_w0 4.wave#*firm_ind_w0 2.wave#*init_lmstat 3.wave#*init_lmstat 4.wave#*init_lmstat 5.wave#*init_lmstat 2.wave#*firm_ind_w0 3.wave#*firm_ind_w0 5.wave#*firm_ind_w0 2.wave#2.sex 3.wave#2.sex 4.wave#2.sex 5.wave#2.sex 2.wave#*agegrp3 3.wave#*agegrp3 4.wave#*agegrp3 5.wave#*agegrp3 2.wave#*educ3 3.wave#*educ3 4.wave#*educ3 5.wave#*educ3  2.wave#*income_cat 3.wave#*income_cat 4.wave#*.income_cat 5.wave#*.income_cat) mlabel("Jordan" "Morocco" "Sudan" "Tunisia" "Egypt" "Jordan" "Morocco" "Sudan" "Tunisia" "Egypt")

 
*Income graph
foreach num of numlist 400 504 729 788 818 { 

estimates restore mfx_tobit_inc_`num'

local c_name: label Lcountry_code `num'
di "`c_name'"
 
mplotoffset, xdim(wave) ylabel(0(10)60) legend(row(1)) plot1opts(msymbol(O)  msize(small)) plot2opts(msymbol(T) msize(small)) plot3opts(msymbol(D)  msize(small)) plot4opts(msymbol(S)  msize(small)) xscale(range(1(1)5)) xlabel(, angle(25)) title("`c_name'", size(large)) plotregion(margin(sides)) ytitle("Hours/week") legend(row(1) span size(medium)) xtitle("")

graph save "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_`num'_hrs.gph", replace
graph export "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_`num'_hrs.png", replace width(1500)

}

grc1leg "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_400_hrs.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_504_hrs.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_729_hrs.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_788_hrs.gph"  "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_818_hrs.gph", col(2) imargin(tiny)

graph display, xsize(14) ysize(20)

*Figure 8

graph save "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_hrs.gph", replace
graph export "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_hrs.png", replace width(1500)




*Initial labour market status graph
foreach num of numlist 400 504 729 788 818 { 

estimates restore mfx_tobit_lmstat_`num'

local c_name: label Lcountry_code `num'
di "`c_name'"
 
mplotoffset, xdim(wave) ylabel(0(20)80) legend(row(1)) plot1opts(msymbol(O)  msize(small)) plot2opts(msymbol(T) msize(small)) plot3opts(msymbol(D)  msize(small)) plot4opts(msymbol(S)  msize(small)) plot5opts(msymbol(X)  msize(small))  xscale(range(1(1)5)) xlabel(, angle(25)) title("`c_name'", size(large)) plotregion(margin(sides)) ytitle("Hours/week") legend(row(3) size(vsmall)) xtitle("")

graph save "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_`num'_hrs.gph", replace
graph export "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_`num'_hrs'.png", replace width(1500)

}


grc1leg "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_400_hrs.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_504_hrs.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_729_hrs.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_788_hrs.gph"  "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_818_hrs.gph"  , col(2) imargin(tiny)

graph display, xsize(14) ysize(20)

*Figure 7

graph save "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_hrs.gph", replace
graph export "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_hrs.png", replace width(1500)


******OLS model**********
*Log hourly wages

foreach num of numlist 400 504 729 788 818 {

reg lnwages_hourly $covs b1.wage_cat [aw=ind_wt] if country==`num' 

estimate store ols_main_`num'

reg lnwages_hourly $covs b1.wage_cat $int i.wave## b1.wage_cat[aw=ind_wt] if country==`num' 

estimate store ols_int_`num'



**margins for income
margins wave#1.wage_cat wave#2.wage_cat wave#3.wage_cat wave#4.wage_cat, post noestimcheck 

estimates store mfx_ols_inc_`num'

estimates restore ols_int_`num'

**margins for initial labor market status
margins wave#2.init_lmstat wave#3.init_lmstat wave#4.init_lmstat wave#5.init_lmstat, post noestimcheck

estimates store mfx_ols_lmstat_`num'

estimates restore ols_int_`num'

}




*Income graph
foreach num of numlist 400 504 729 788 818 { 

estimates restore mfx_ols_inc_`num'

local c_name: label Lcountry_code `num'
di "`c_name'"
 
mplotoffset, xdim(wave) ylabel(0(1)3) legend(row(1)) plot1opts(msymbol(O)  msize(small)) plot2opts(msymbol(T) msize(small)) plot3opts(msymbol(D)  msize(small)) plot4opts(msymbol(S)  msize(small)) xscale(range(1(1)5)) xlabel(, angle(25)) title("`c_name'", size(large)) plotregion(margin(sides)) ytitle("log hourly wages") legend(row(1) size(medium)) xtitle("")

graph save "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_`num'_wgs.gph", replace
graph export "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_`num'_wgs.png", replace width(1500)

}

grc1leg "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_400_wgs.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_504_wgs.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_729_wgs.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_788_wgs.gph"  "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_818_wgs.gph", col(2) imargin(tiny)

graph display, xsize(14) ysize(20)

*Figure 12

graph save "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_wgs.gph", replace
graph export "Data/Do files/Workers paper/grph png tables/WP_mfx_inc_wgs.png", replace width(1500)



*Initial labour market status graph

foreach num of numlist 400 504 729 788 818 { 

estimates restore mfx_ols_lmstat_`num'

local c_name: label Lcountry_code `num'
di "`c_name'"
 
mplotoffset, xdim(wave) ylabel(0(1)3) legend(row(1)) plot1opts(msymbol(O)  msize(small)) plot2opts(msymbol(T) msize(small)) plot3opts(msymbol(D)  msize(small)) plot4opts(msymbol(S)  msize(small))    xscale(range(1(1)5)) xlabel(, angle(25)) title("`c_name'", size(large)) plotregion(margin(sides)) ytitle("log hourly wages") legend(row(3) size(vsmall)) xtitle("")

graph save "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_`num'_wgs.gph", replace
graph export "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_`num'_wgs.png", replace width(1500)

}


grc1leg "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_400_wgs.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_504_wgs.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_729_wgs.gph" "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_788_wgs.gph"  "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_818_wgs.gph"  , col(2) imargin(tiny) legendfrom("Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_818_wgs.gph")

graph display, xsize(14) ysize(20)

*Figure 11

graph save "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_wgs.gph", replace
graph export "Data/Do files/Workers paper/grph png tables/WP_mfx_lmstat_wgs.png", replace width(1500)

*Table A8/A9

esttab ols_main_* ols_int_* using "Data/Do files/Workers paper/grph png tables/ols.csv", cells(b(star fmt(3)) se(par)) stats(N r2, labels("(N (Obs.)" `"R-sq."') fmt(%9.0g %9.3f)) varlabels(_cons "Constant" 2.wave "Feb. 2021" 3.wave "April 2021" 4.wave "June 2021" 5.wave "Aug. 2021") replace noomit nobase refcat(1.init_lmstat "Feb. 2020 labor market status (Public wage omit.)" 2.sex "Sex (Male omit.)" 2.wave "Wave (First wave omit.)" 2.agegrp3 "Age group (18-29 omitted)" 2.educ3 "Education  (basic or less omit.)" 1.firm_ind_w0 "Industry (Services omit.)" 2.wave#1.init_lmstat "Wave and Feb. 2020 labor market status int." 2.wage_cat "Feb. 2020 wage quart. (first quart. omit.)"  2.wave#1.firm_ind_w0 "Wave and Feb. 2020 industry int." 2.wave#2.sex "Wave and sex int." 2.wave#2.agegrp3 "Wave and age int." 2.wave#2.educ3 "Wave and educ. int." 2.wave#2.wage_cat "Wave and Feb. 2020 wage int.", label(" ")) label order(2.wave 3.wave 4.wave 5.wave ?.init_lmstat ?.firm_ind_w0 2.sex ?.agegrp3 ?.educ3 ?.wage_cat 2.wave#*init_lmstat 3.wave#*init_lmstat 4.wave#*init_lmstat 5.wave#*init_lmstat 2.wave#*firm_ind_w0 3.wave#*firm_ind_w0 4.wave#*firm_ind_w0 5.wave#*firm_ind_w0  2.wave#2.sex 3.wave#2.sex 4.wave#2.sex 5.wave#2.sex 2.wave#*agegrp3 3.wave#*agegrp3 4.wave#*agegrp3 5.wave#*agegrp3 2.wave#*educ3 3.wave#*educ3 4.wave#*educ3 5.wave#*educ3  2.wave#*wage_cat 3.wave#*wage_cat 4.wave#*.wage_cat 5.wave#*.wage_cat) mlabel("Jordan" "Morocco" "Sudan" "Tunisia" "Egypt" "Jordan" "Morocco" "Sudan" "Tunisia" "Egypt")


