/*COVID-19 Workers Paper Models
Author: CK, RA
Original: January 28 2022
Updated: 2022.09.19
Version: 8 REP

*/

*Graph formatting setup
grstyle clear 

*Initializing grstyle
grstyle init

*Graph formatting setup
*Font
graph set window fontface "Calibri"
grstyle set size 10pt: heading
grstyle set size 10pt: subheading axis_title
grstyle set size 10pt: tick_label key_label

*Starting with the basic style
grstyle set plain
*Setting to ILO colors in CMYK
/* ordered grstyle set color "38 35 89" "0 85 167" "2 181 207" "205 216 228"  "144 204 130" "248 196 35" "231 77 94" "133 0 85" 
*/
grstyle set color "38 35 89" "2 181 207" "144 204 130" "231 77 94" "248 196 35"   "133 0 85" "0 85 167" "205 216 228" 
*Setting font size generally to 12 (does not get bar labels)
grstyle set size 12pt: axis_title tick_label key_label text_option subheading
*Setting graph size to 6.7 inches wide 3.2 high
grstyle set graphsize 3.2 6.7
*Turning off grids with width zero
grstyle set linewidth 0: major_grid minor_grid
*Making axes grey
grstyle set color gs7: axisline tick major_grid xyline minor_grid minortick matrix matrixmarkline grid refmarker refmarkline


use "Data/Eat/Workers analysis data.dta", clear

estimates clear 

*Label waves
la def Lwave 1 "11/20" 2 "2/21" 3 "4/21" 4 "6/21" 5 "8/21"
la val wave Lwave

******Mlogit model**********


foreach num2 of numlist 1/3 {
	
mlogit lm_stat b788.country##b1.wave [aw=ind_wt], base(1) rrr

*For actual waves
margins 400.country#2.wave 400.country#4.wave 400.country#5.wave 504.country#1.wave 504.country#2.wave 504.country#3.wave 504.country#4.wave 729.country#3.wave 729.country#5.wave 788.country#1.wave 788.country#2.wave 788.country#3.wave 788.country#4.wave 818.country#2.wave 818.country#4.wave, noestimcheck post predict(outcome(`num2'))

estimate store mlogit_main_`num2'

}

mlogit lm_stat b788.country##b1.wave, base(1) rrr
mlogtest, iia


*Labor market status cross-country graph

foreach num2 of numlist 1/3 {
estimates restore mlogit_main_`num2'

local c_stat: label Llm_stat `num2'
di "`c_stat'"
 
mplotoffset, xdim(wave) ylabel(0(.2).6) legend(row(1)) plot1opts(msymbol(O)  msize(small)) plot2opts(msymbol(T) msize(small)) plot3opts(msymbol(D)  msize(small)) plot4opts(msymbol(S)  msize(small))  xscale(range(1(1)5)) xlabel(, labsize(medsmall) angle(25)) title("`c_stat'", size(medium)) plotregion(margin(sides)) ytitle("Probability", size(medium)) legend(row(2) size(medsmall)) xtitle("")

graph save "Data/Do files/Workers paper/grph png tables/WP_main_mlogit_`num2'.gph", replace
graph export "Data/Do files/Workers paper/grph png tables/WP_main_mlogit_`num2'.png", replace width(1500)

}



grc1leg "Data/Do files/Workers paper/grph png tables/WP_main_mlogit_1.gph"  "Data/Do files/Workers paper/grph png tables/WP_main_mlogit_2.gph" "Data/Do files//Workers paper/grph png tables/WP_main_mlogit_3.gph", row(3) imargin(tiny)

graph display, xsize(14) ysize(20)

*Figure 3
graph save "Data/Do files/Workers paper/grph png tables/WP_mlogit_main.gph", replace
graph export "Data/Do files/Workers paper/grph png tables/WP_mlogit_main.png", replace width(1500)



******Tobit model************
tobit cor29 b788.country##b1.wave [aw=ind_wt], ll(0)

margins 400.country#2.wave 400.country#4.wave 400.country#5.wave 504.country#1.wave 504.country#2.wave 504.country#3.wave 504.country#4.wave 729.country#3.wave 729.country#5.wave 788.country#1.wave 788.country#2.wave 788.country#3.wave 788.country#4.wave 818.country#2.wave 818.country#4.wave, noestimcheck post

estimate store tobit_main

mplotoffset, xdim(wave) ylabel(0(10)50) legend(row(1)) plot1opts(msymbol(O)  msize(small)) plot2opts(msymbol(T) msize(small)) plot3opts(msymbol(D) msize(small)) plot4opts(msymbol(S)  msize(small)) xscale(range(1(1)5)) xlabel(, angle(25)) plotregion(margin(sides))  title(" ") ytitle("Hours/week") legend(row(1) size(medium)) xtitle("")

*Figure 6

graph save "Data/Do files/Workers paper/grph png tables/WP_tobit_main_hrs.gph", replace
graph export "Data/Do files/Workers paper/grph png tables/WP_tobit_main_hrs.png", replace width(1500)


******OLS model**********
*Log hourly wages
reg lnwages_hourly b788.country##b1.wave [aw=ind_wt] 

margins 400.country#2.wave 400.country#4.wave 400.country#5.wave 504.country#1.wave 504.country#2.wave 504.country#3.wave 504.country#4.wave 729.country#3.wave 729.country#5.wave 788.country#1.wave 788.country#2.wave 788.country#3.wave 788.country#4.wave 818.country#2.wave 818.country#4.wave, noestimcheck post

estimate store ols_main

mplotoffset, xdim(wave) ylabel(0(1)2) legend(row(1)) plot1opts(msymbol(O)  msize(small)) plot2opts(msymbol(T) msize(small)) plot3opts(msymbol(D)  msize(small)) plot4opts(msymbol(S)  msize(small))    xscale(range(1(1)5)) xlabel(, angle(25)) title(" ") plotregion(margin(sides)) ytitle("log hourly wages") legend(row(1) size(medium)) xtitle("")

*Figure 9

graph save "Data/Do files/Workers paper/grph png tables/WP_ols_main.gph", replace
graph export "Data/Do files/Workers paper/grph png tables/WP_ols_main.png", replace width(1500)

**Table A3: Country models
esttab *main* using "Data/Do files/Workers paper/grph png tables/main.csv", cells(b(fmt(3)) se(par)) stats(N, labels("N (Obs.)") fmt(%9.0g)) mlabel("Prob. Emp." "Prob. Unemp." "Prob. OLF" "Hours/week" "Ln(hourly wage)") label replace
