/*Workers paper Data Prep 
Author: RC, CK
Original: November 1 2021
Updated: March 21 2022
Version: 12 REP */


*********
*COVID-19 monitor data
*********

use "Data/Combined data/COVID-19 Monitor All HH 2020-2021 rep xs v5.0.dta", clear

*Drop Baseera
drop if wave==1 & country==818

*********Create Variables

**Hourly Wages
*refused/don't know responses
replace wor8 = . if wor8 == 99998
replace wor8 = . if wor8 == 99996

replace wor7 = . if wor7 == 99998
replace wor7 = . if wor7 == 99996

*Winsorize
foreach num of numlist 400 504 729 788 818 {

sum wor8 if country==`num', detail
replace wor8=`r(p95)' if wor8>`r(p95)' & country==`num' & wor8!=.

sum wor7 if  country==`num', detail
replace wor7=`r(p95)' if wor7>`r(p95)' & country==`num' & wor7!=.
}

*Hourly wages as monthly/weeks/hours per week
gen wages_hourly = wor8/4.33/cor29
*Into USD
replace wages_hourly=wages_hourly/0.709 if country==400
replace wages_hourly=wages_hourly/8.76539 if country==504
replace wages_hourly=wages_hourly/55.0839 if country==729
replace wages_hourly=wages_hourly/2.65202 if country==788
replace wages_hourly=wages_hourly/15.755 if country==818

gen lnwages_hourly=ln(wages_hourly)

**Initial labor market status 

*Public
gen newcat=0 if cor18==5
*Formal private
replace newcat = 1 if wor4_w0 == 1 & cor18==6
*Informal in est.
replace newcat = 2 if wor4_w0 == 2 & wor5_w0 == 1 & cor18==6
*Informal out est.
replace newcat = 3 if wor4_w0 == 2 & wor5_w0 == 2 & cor18==6

clonevar cor18_rev=cor18 if cor18!=5 & cor18!=6

foreach var of varlist cor18_rev {
*Non-wage, spacing
	recode `var' (1/4=1) (7=6) (8/11=7)
}


*Combining
replace cor18_rev=2 if newcat==0
replace cor18_rev=3 if newcat==1
replace cor18_rev=4 if newcat==2
replace cor18_rev=5 if newcat==3

la def Llmstat 1 "Non-wage" 2 "Public wage" 3 "Formal private wage" 4 "Informal priv. wage in an est." 5 "Informal priv. wage outside est." 6 "Unemployed" 7 "Out of LF" 10 "Total"
la val cor18_rev Llmstat

rename cor18_rev init_lmstat
tabu init_lmstat cor18, miss

**Firm industry end of Feb 2020
*Manufacturing & agriculture, farmers
gen firm_ind_w0 =1 if (hhe1_w0>=1 & hhe1_w0<=2) | (wor1_w0>=1 & wor1_w0<=2) | cor18==1 | cor18==3
*Construction
replace firm_ind_w0=2 if hhe1_w0==3 | wor1_w0==3
*Trade/retail
replace firm_ind_w0=3 if hhe1_w0==4 | wor1_w0==4
*Accommodation/food
replace firm_ind_w0=4 if hhe1_w0==6  | wor1_w0==6
*Services (includes UFW non-ag)
replace firm_ind_w0=5 if inlist(hhe1_w0,5,7,8,9,10,11) | inlist(wor1_w0,5,7,8,9,10,11) | cor18==4
*Not employed
replace firm_ind_w0=0 if init_lmstat==6 | init_lmstat==7

la def Lfirm_ind 0 "Not employed" 1 "Manufacturing & agriculture" 2 "Construction" 3 "Trade/retail" 4 "Accommodations/food" 5 "Services"

la val firm_ind_w0 Lfirm_ind

fre firm_ind_w0

tabu init_lmstat firm_ind_w0, miss


*agegrp recode

recode age (18/29=1) (30/49=2) (50/64=3) , gen(agegrp3)
la def Lagegrp3 1 "18-29" 2 "30-49" 3 "50-64" 
la val agegrp3 Lagegrp3

fre agegrp3 

*education recode
recode educ (2=1) (3=2) (4=3), gen(educ3)
la def Leduc3 1 "Basic or less" 2 "Secondary" 3 "Higher education"
la val educ3 Leduc3 

*Marital recode
recode marital (3=2), gen(marital2)
la def Lmarital2 1 "Single" 2 "Ever married"
la val marital2 Lmarital2

fre marital2

*Income recode
recode cor22 (.=5) (6=5), gen(income_cat)

la def Lincome 1 "First" 2 "Second" 3 "Third" 4 "Fourth" 5 "Don't know/refused/missing"
la val income_cat Lincome

**Feb 2020 wage quartiles

gen wage_cat=.

foreach num of numlist 400 504 729 788 818 {

capture drop wage_quart
xtile wage_quart= wor7 [aw=ind_wt] if country==`num', n(4)
replace wage_cat=wage_quart if country==`num'

}
drop wage_quart
recode wage_cat (.=5)

la val wage_cat Lincome

save "Data/Eat/Workers analysis data.dta", replace
