/*COVID-19 Workers Paper Descriptives
Author: AL, CK
Original: September 30 2021
Updated: March 31 2022
Version: 10 REP

*/

*Graph formatting setup
grstyle clear 

*Initializing grstyle
grstyle init

*Graph formatting setup
*Font
graph set window fontface "Calibri"
grstyle set size 10pt: heading
grstyle set size 10pt: subheading axis_title
grstyle set size 10pt: tick_label key_label

*Starting with the basic style
grstyle set plain
*Setting to ILO colors in CMYK
/* ordered grstyle set color "38 35 89" "0 85 167" "2 181 207" "205 216 228"  "144 204 130" "248 196 35" "231 77 94" "133 0 85" 
*/
grstyle set color "38 35 89" "2 181 207" "144 204 130" "231 77 94" "248 196 35"   "133 0 85" "0 85 167" "205 216 228" 
*Setting font size generally to 12 (does not get bar labels)
grstyle set size 12pt: axis_title tick_label key_label text_option subheading
*Setting graph size to 6.7 inches wide 3.2 high
grstyle set graphsize 3.2 6.7
*Turning off grids with width zero
grstyle set linewidth 0: major_grid minor_grid
*Making axes grey
grstyle set color gs7: axisline tick major_grid xyline minor_grid minortick matrix matrixmarkline grid refmarker refmarkline


use "Data/Eat/Workers analysis data.dta", clear

*Label waves
la def Lwave 0 "Feb. 2020" 1 "Nov. 2020" 2 "Feb. 2021" 3 "April 2021" 4 "June 2021" 5 "Aug. 2021"
la val wave Lwave

***Stats: Feb. 2020 among employed

tabu country init_lmstat if cor18>=1 & cor18<=6 [aw=ind_wt], row nofreq

***Figure: Gini wages


expand 2

bysort indid: replace wor8=wor7 if _n==2

bysort indid: replace wave=0 if _n==2


*Drop Sudan
drop if country==729


* Figure 10: 75/25
collapse  (p25) p25=wor8 (p75) p75=wor8 [aw=ind_wt], by(country wave)

gen r75_25=p75/p25

graph bar r75_25, over(wave) over(country) asyvars ytitle("75th/25th percentile ratio") blabel(bar, format(%4.2f) size(small))

graph save "Data/Do files/Workers paper/grph png tables/WP_wagesp75_25.gph", replace
graph export "Data/Do files/Workers paper/grph png tables/WP_wagesp75_25.png", replace width(1500)


***Table A2: Summary stats on variables

use "Data/Eat/Workers analysis data.dta", clear

clonevar wage_cat_wg_only=wage_cat if init_lmstat>=2 & init_lmstat<=5
clonevar firm_ind_w0_emp_only=firm_ind_w0 if init_lmstat>=1 & init_lmstat<=5

la var income_cat "Feb. 2020 household income quartile (approximate)" 
la var educ3 "Education level"
la var lm_stat "Labour market status (at wave)"
la var init_lmstat "Feb. 2020 detailed labour market status"
la var agegrp3 "Age group"
la var firm_ind_w0_emp_only "Feb. 2020 industry (Feb. 2020 employed only)"
la var wage_cat_wg_only "Feb. 2020 wage quartile (Feb. 2020 wage workers only)"

la def waves 1 "Nov. 2021" 2 "Feb. 2021" 3 "June 2021" 4 "April 2021" 5 "August 2021"
la val wave waves 

tabout wave sex agegrp3 educ3 init_lmstat firm_ind_w0_emp_only income_cat wage_cat_wg_only lm_stat country [aw=ind_wt] using "Data/Do files/Workers paper/grph png tables/Descriptivestats.xls", f(1) npos(row) c(col) clab(_) ptotal(none) replace 

la var cor29 "Hours worked"
la var lnwages_hourly "Ln(hourly wages)"

tabout country [aw=ind_wt] using "Data/Do files/Workers paper/grph png tables/Descriptivestats.xls", sum append f(2) c(mean cor29 mean lnwages_hourly)

